@@ -39,7 +39,7 @@ const startState = new stepfunctions.Pass(this, 'StartState');
 
 new LambdaToStepfunctions(this, 'LambdaToStepfunctionsPattern', {
   lambdaFunctionProps: {
-    runtime: lambda.Runtime.NODEJS_14_X,
+    runtime: lambda.Runtime.NODEJS_16_X,
     handler: 'index.handler',
     code: lambda.Code.fromAsset(`lambda`)
   },
@@ -91,7 +91,7 @@ final Pass startState = new Pass(this, "StartState");
 new LambdaToStepfunctions(this, "test-lambda-stepfunctions-stack",
         new LambdaToStepfunctionsProps.Builder()
                 .lambdaFunctionProps(new FunctionProps.Builder()
-                        .runtime(Runtime.NODEJS_14_X)
+                        .runtime(Runtime.NODEJS_16_X)
                         .code(Code.fromAsset("lambda"))
                         .handler("index.handler")
                         .build())
@@ -112,7 +112,7 @@ new LambdaToStepfunctions(this, "test-lambda-stepfunctions-stack",
 |logGroupProps?|[`logs.LogGroupProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_logs.LogGroupProps.html)|User provided props to override the default props for for the CloudWatchLogs LogGroup.|
 |stateMachineEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the ARN of the state machine. Default: STATE_MACHINE_ARN |
 |existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and an Interface Endpoint will be created in the VPC for Amazon Step Functions. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
-|vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
+|vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overridden. If `deployVpc` is not `true` then this property will be ignored.|
 |deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
 
 ## Pattern Properties
@@ -151,7 +151,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -167,16 +167,16 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_cloudwatch
-import aws_cdk.aws_ec2
-import aws_cdk.aws_lambda
-import aws_cdk.aws_logs
-import aws_cdk.aws_stepfunctions
-import constructs
+import aws_cdk.aws_cloudwatch as _aws_cdk_aws_cloudwatch_ceddda9d
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import aws_cdk.aws_logs as _aws_cdk_aws_logs_ceddda9d
+import aws_cdk.aws_stepfunctions as _aws_cdk_aws_stepfunctions_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class LambdaToStepfunctions(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-lambda-stepfunctions.LambdaToStepfunctions",
 ):
@@ -186,18 +186,18 @@ class LambdaToStepfunctions(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        state_machine_props: typing.Union[_aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps, typing.Dict[builtins.str, typing.Any]],
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
         state_machine_environment_variable_name: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -217,22 +217,7 @@ class LambdaToStepfunctions(
         :summary: Constructs a new instance of the LambdaToStepfunctionsProps class.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                deploy_vpc: typing.Optional[builtins.bool] = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                state_machine_environment_variable_name: typing.Optional[builtins.str] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__41a3edd12d240c4efadcccf7c9a4e09b79a41847dbd7dce480053f8e1adccdd4)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = LambdaToStepfunctionsProps(
@@ -251,30 +236,30 @@ class LambdaToStepfunctions(
 
     @builtins.property
     @jsii.member(jsii_name="lambdaFunction")
-    def lambda_function(self) -> aws_cdk.aws_lambda.Function:
-        return typing.cast(aws_cdk.aws_lambda.Function, jsii.get(self, "lambdaFunction"))
+    def lambda_function(self) -> _aws_cdk_aws_lambda_ceddda9d.Function:
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.Function, jsii.get(self, "lambdaFunction"))
 
     @builtins.property
     @jsii.member(jsii_name="stateMachine")
-    def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
-        return typing.cast(aws_cdk.aws_stepfunctions.StateMachine, jsii.get(self, "stateMachine"))
+    def state_machine(self) -> _aws_cdk_aws_stepfunctions_ceddda9d.StateMachine:
+        return typing.cast(_aws_cdk_aws_stepfunctions_ceddda9d.StateMachine, jsii.get(self, "stateMachine"))
 
     @builtins.property
     @jsii.member(jsii_name="stateMachineLogGroup")
-    def state_machine_log_group(self) -> aws_cdk.aws_logs.ILogGroup:
-        return typing.cast(aws_cdk.aws_logs.ILogGroup, jsii.get(self, "stateMachineLogGroup"))
+    def state_machine_log_group(self) -> _aws_cdk_aws_logs_ceddda9d.ILogGroup:
+        return typing.cast(_aws_cdk_aws_logs_ceddda9d.ILogGroup, jsii.get(self, "stateMachineLogGroup"))
 
     @builtins.property
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
-    ) -> typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]]:
-        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_cloudwatch.Alarm]], jsii.get(self, "cloudwatchAlarms"))
+    ) -> typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]]:
+        return typing.cast(typing.Optional[typing.List[_aws_cdk_aws_cloudwatch_ceddda9d.Alarm]], jsii.get(self, "cloudwatchAlarms"))
 
     @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], jsii.get(self, "vpc"))
+    def vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], jsii.get(self, "vpc"))
 
 
 @jsii.data_type(
@@ -296,15 +281,15 @@ class LambdaToStepfunctionsProps:
     def __init__(
         self,
         *,
-        state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
+        state_machine_props: typing.Union[_aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps, typing.Dict[builtins.str, typing.Any]],
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         deploy_vpc: typing.Optional[builtins.bool] = None,
-        existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+        existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+        lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
         state_machine_environment_variable_name: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param state_machine_props: User provided StateMachineProps to override the defaults. Default: - None
@@ -320,28 +305,15 @@ class LambdaToStepfunctionsProps:
         :summary: Properties for the LambdaToStepfunctions class.
         '''
         if isinstance(state_machine_props, dict):
-            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
+            state_machine_props = _aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps(**state_machine_props)
         if isinstance(lambda_function_props, dict):
-            lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+            lambda_function_props = _aws_cdk_aws_lambda_ceddda9d.FunctionProps(**lambda_function_props)
         if isinstance(log_group_props, dict):
-            log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
+            log_group_props = _aws_cdk_aws_logs_ceddda9d.LogGroupProps(**log_group_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = _aws_cdk_aws_ec2_ceddda9d.VpcProps(**vpc_props)
         if __debug__:
-            def stub(
-                *,
-                state_machine_props: typing.Union[aws_cdk.aws_stepfunctions.StateMachineProps, typing.Dict[str, typing.Any]],
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                deploy_vpc: typing.Optional[builtins.bool] = None,
-                existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                state_machine_environment_variable_name: typing.Optional[builtins.str] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__262dee4e621f3820477421afbb336e7fcf75893d3fa3bd00b46f35db85d2e956)
             check_type(argname="argument state_machine_props", value=state_machine_props, expected_type=type_hints["state_machine_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
             check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
@@ -351,7 +323,7 @@ class LambdaToStepfunctionsProps:
             check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
             check_type(argname="argument state_machine_environment_variable_name", value=state_machine_environment_variable_name, expected_type=type_hints["state_machine_environment_variable_name"])
             check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "state_machine_props": state_machine_props,
         }
         if create_cloud_watch_alarms is not None:
@@ -372,14 +344,16 @@ class LambdaToStepfunctionsProps:
             self._values["vpc_props"] = vpc_props
 
     @builtins.property
-    def state_machine_props(self) -> aws_cdk.aws_stepfunctions.StateMachineProps:
+    def state_machine_props(
+        self,
+    ) -> _aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps:
         '''User provided StateMachineProps to override the defaults.
 
         :default: - None
         '''
         result = self._values.get("state_machine_props")
         assert result is not None, "Required property 'state_machine_props' is missing"
-        return typing.cast(aws_cdk.aws_stepfunctions.StateMachineProps, result)
+        return typing.cast(_aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps, result)
 
     @builtins.property
     def create_cloud_watch_alarms(self) -> typing.Optional[builtins.bool]:
@@ -400,39 +374,43 @@ class LambdaToStepfunctionsProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
+    def existing_lambda_obj(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function]:
         '''Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error.
 
         :default: - None
         '''
         result = self._values.get("existing_lambda_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function], result)
 
     @builtins.property
-    def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def existing_vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''An existing VPC for the construct to use (construct will NOT create a new VPC in this case).'''
         result = self._values.get("existing_vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     @builtins.property
     def lambda_function_props(
         self,
-    ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
+    ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''User provided props to override the default props for the Lambda function.
 
         :default: - Default properties are used.
         '''
         result = self._values.get("lambda_function_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps], result)
 
     @builtins.property
-    def log_group_props(self) -> typing.Optional[aws_cdk.aws_logs.LogGroupProps]:
+    def log_group_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps]:
         '''User provided props to override the default props for the CloudWatchLogs LogGroup.
 
         :default: - Default props are used
         '''
         result = self._values.get("log_group_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_logs.LogGroupProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_logs_ceddda9d.LogGroupProps], result)
 
     @builtins.property
     def state_machine_environment_variable_name(self) -> typing.Optional[builtins.str]:
@@ -444,10 +422,10 @@ class LambdaToStepfunctionsProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+    def vpc_props(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps]:
         '''Properties to override default properties if deployVpc is true.'''
         result = self._values.get("vpc_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -467,3 +445,35 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__41a3edd12d240c4efadcccf7c9a4e09b79a41847dbd7dce480053f8e1adccdd4(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    state_machine_props: typing.Union[_aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps, typing.Dict[builtins.str, typing.Any]],
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    deploy_vpc: typing.Optional[builtins.bool] = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    state_machine_environment_variable_name: typing.Optional[builtins.str] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__262dee4e621f3820477421afbb336e7fcf75893d3fa3bd00b46f35db85d2e956(
+    *,
+    state_machine_props: typing.Union[_aws_cdk_aws_stepfunctions_ceddda9d.StateMachineProps, typing.Dict[builtins.str, typing.Any]],
+    create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+    deploy_vpc: typing.Optional[builtins.bool] = None,
+    existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    log_group_props: typing.Optional[typing.Union[_aws_cdk_aws_logs_ceddda9d.LogGroupProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    state_machine_environment_variable_name: typing.Optional[builtins.str] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
